enum ExpressionKind: string
Public API: explicitly declared with @visibility public.

The semantic operation represented by an expression.

Reading semantic factsdoctest
\SqlSemantics\Core\Model\ExpressionKind::Coalesce->value // => 'coalesce'

Cases

case Column = 'column'
case Literal = 'literal'
case Parameter = 'parameter'
case Operator = 'operator'
case Coalesce = 'coalesce'
case NullIf = 'null-if'
case Cast = 'cast'

Test cases 26

Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.

Dedicated tests 1
Other tests reaching this symbol 25

Relations

Constant reads 9
Type declarations 1