enum JoinKind: string
Public API: explicitly declared with @visibility public.

The logical join operation, before physical planning.

Reading semantic factsdoctest
\SqlSemantics\Core\Model\JoinKind::Left->value // => 'left'

Cases

case Cross = 'cross'
case Inner = 'inner'
case Left = 'left'
case Right = 'right'
case Full = 'full'

Test cases 15

Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.

Dedicated tests 1
Other tests reaching this symbol 14

Relations

Constant reads 16
Type declarations 3