enumExpressionKind
enum ExpressionKind: string
Public API: explicitly declared with
@visibility public.The semantic operation represented by an expression.
\SqlSemantics\Core\Model\ExpressionKind::Coalesce->value // => 'coalesce'Cases
case Column = 'column'case Literal = 'literal'case Parameter = 'parameter'case Operator = 'operator'case Coalesce = 'coalesce'case NullIf = 'null-if'case Cast = 'cast'Test cases 26
Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.
Dedicated tests 1
Other tests reaching this symbol 25
ExpressionBinderTest::testCallRetainsNestedCoalesceInputscallsExpressionRulesTest::testCoerceRecordsPostgresCommonTypeConversionscallsLiteralBinderTest::testBindParametersRemainExplicitlyUnknownWithoutBindingscallsNullFactsTest::testStrictAndCoalesceFactscallsSelectModifiersBinderTest::testSortExpressionDoesNotResolveAStringLiteralAsAnAliascallsDialectTestcallsPlatformTestcallsNameRulesTestcallsQueryRulesTestcallsSchemaRulesTestcallsSyntaxRulesTestcallsTypeRulesTest::testArithmeticRetainsLanguageSemanticscallsTypeRulesTest::testCoalescePreservesOperandscallsTypeRulesTest::testCommonPreservesHomogeneousTypecallsTypeRulesTest::testPredicateAcceptsBooleanResultscallsTypeRulesTest::testProjectPreservesTypedValuescallsNameRulesTestcallsPlatformTestcallsQueryRulesTestcallsSchemaRulesTestcallsTypeRulesTest::testArithmeticRetainsLanguageSemanticscallsTypeRulesTest::testCoalescePreservesOperandscallsTypeRulesTest::testCommonPreservesHomogeneousTypecallsTypeRulesTest::testPredicateAcceptsBooleanResultscallsTypeRulesTest::testProjectPreservesTypedValuescalls
Relations
Constant reads 9
- class-const SqlSemantics\Platform\PostgreSql\TypeRules::arithmetic() packages/sql-semantics-postgres/src/TypeRules.php:191
- class-const SqlSemantics\Platform\PostgreSql\TypeRules::project() packages/sql-semantics-postgres/src/TypeRules.php:229
- class-const SqlSemantics\Core\Binding\ExpressionRules::call() packages/sql-semantics/src/Core/Binding/ExpressionRules.php:43
- class-const SqlSemantics\Core\Binding\ExpressionRules::call() packages/sql-semantics/src/Core/Binding/ExpressionRules.php:51
- class-const SqlSemantics\Core\Binding\ExpressionRules::coerce() packages/sql-semantics/src/Core/Binding/ExpressionRules.php:66
- class-const SqlSemantics\Core\Binding\ExpressionRules::operator() packages/sql-semantics/src/Core/Binding/ExpressionRules.php:98
- class-const SqlSemantics\Core\Binding\LiteralBinder::bind() packages/sql-semantics/src/Core/Binding/LiteralBinder.php:36
- class-const SqlSemantics\Core\Binding\LiteralBinder::bind() packages/sql-semantics/src/Core/Binding/LiteralBinder.php:43
- class-const SqlSemantics\Core\Binding\Scope::column() packages/sql-semantics/src/Core/Binding/Scope.php:60